@@ -23,7 +23,7 @@ def dirbrute():
         if response == 200:
 
             print(Style.BRIGHT + Fore.GREEN + "[200] " + Fore.WHITE + "Valid Path Found: " + Style.BRIGHT + path_of_url + Style.RESET_ALL)
-            os.system('sudo touch DIR-BRUTE_result.txt')
+            os.system('touch DIR-BRUTE_result.txt')
             file = open('DIR-BRUTE_result.txt', "a")
             file.write((str(response)) + ": " + path_of_url)
 
